@@ -1,18 +1,22 @@
-Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
-Components.utils.import("resource://gre/modules/AddonManager.jsm");
+var { interfaces: Ci, utils: Cu, classes: Cc } = Components;
 
-const Ci = Components.interfaces;
-const Cc = Components.classes;
-const Cr = Components.results;
+Cu.import("resource://gre/modules/XPCOMUtils.jsm");
+Cu.import("resource://gre/modules/imXPCOMUtils.jsm");
+Cu.import("resource://gre/modules/AddonManager.jsm");
+Cu.import("resource://gre/modules/Preferences.jsm");
 
-const SERVICE_CTRID = "@torproject.org/torbirdy;1";
-const SERVICE_ID    = Components.ID("{ebd85413-18c8-4265-a708-a8890ec8d1ed}");
-const SERVICE_NAME  = "Main TorBirdy Component";
-const TB_ID         = "castironthunderbirdclub@torproject.org";
+var SERVICE_CTRID = "@torproject.org/torbirdy;1";
+var SERVICE_ID    = Components.ID("{ebd85413-18c8-4265-a708-a8890ec8d1ed}");
+var SERVICE_NAME  = "Main TorBirdy Component";
+var TB_ID         = "castironthunderbirdclub@torproject.org";
 
-const kPrefBranch     = "extensions.torbirdy.custom.";
-const kRestoreBranch  = "extensions.torbirdy.restore.";
-const kTorBirdyBranch = "extensions.torbirdy.";
+var kPrefBranch     = "extensions.torbirdy.custom.";
+var kRestoreBranch  = "extensions.torbirdy.restore.";
+var kTorBirdyBranch = "extensions.torbirdy.";
+
+XPCOMUtils.defineLazyGetter(this, "_", () =>
+  l10nHelper("chrome://castironthunderbirdclub/locale/torbirdy.properties")
+);
 
 // Default preference values for TorBirdy.
 // These preferences values will be "enforced": even if the user decides to
@@ -23,14 +27,9 @@ const kTorBirdyBranch = "extensions.torbirdy.";
 // the secure default when Thunderbird starts.
 // There are some preferences that can be overwritten using TorBirdy's
 // preferences dialog. See `preferences.js'.
-const TorBirdyPrefs = {
+var TorBirdyPrefs = {
   "extensions.torbirdy.protected": false,
-  // When the preferences below have been set, then only enable TorBirdy.
-  // Generate our own custom time-independent message-ID.
-  "mailnews.custom_message_id": true,
-  "mailnews.header.custom_message_id": "",
-  // Remove the date header.
-  "mailnews.local_date_header_generation": false,
+  // When the preferences below have been set, enable TorBirdy.
 
   /*
     Network
@@ -38,6 +37,10 @@ const TorBirdyPrefs = {
 
   // Use a manual proxy configuration.
   "network.proxy.type": 1,
+  // https://bugs.torproject.org/10419
+  "network.proxy.no_proxies_on": "",
+  // Restrict TBB ports.
+  "network.security.ports.banned": "9050,9051,9150,9151",
   // Number of seconds to wait before attempting to recontact an unresponsive proxy server.
   "network.proxy.failover_timeout": 1800,
 
@@ -48,6 +51,8 @@ const TorBirdyPrefs = {
 
   // Set DNS proxying through SOCKS5.
   "network.proxy.socks_remote_dns": true,
+  // Disable DNS prefetching.
+  "network.dns.disablePrefetch": true,
 
   // https://lists.torproject.org/pipermail/tor-talk/2011-September/021398.html
   // "Towards a Tor-safe Mozilla Thunderbird"
@@ -62,8 +67,15 @@ const TorBirdyPrefs = {
 
   // Likely privacy violations
   // https://blog.torproject.org/blog/experimental-defense-website-traffic-fingerprinting
-  // https://trac.torproject.org/projects/tor/ticket/3914
+  // https://bugs.torproject.org/3914
   "network.http.pipelining": true,
+  "network.http.pipelining.aggressive": true,
+  "network.http.pipelining.maxrequests": 12,
+  "network.http.connection-retry-timeout": 0,
+  "network.http.max-persistent-connections-per-proxy": 256,
+  "network.http.pipelining.reschedule-timeout": 15000,
+  "network.http.pipelining.read-timeout": 60000,
+
   // We do not fully understand the privacy issues of the SPDY protocol
   // We have no reason to believe that anyone would actually use it with
   // Thunderbird but we fail closed to keep users safe out of an abundance of
@@ -74,8 +86,10 @@ const TorBirdyPrefs = {
   // author Mike Perry.
   "network.http.pipelining.ssl": true,
   "network.http.proxy.pipelining": true,
-  "network.http.pipelining.maxrequests": 12,
-  "network.http.sendRefererHeader": 0,
+  "network.http.sendRefererHeader": 2,
+  // https://bugs.torproject.org/16673
+  "network.http.altsvc.enabled": false,
+  "network.http.altsvc.oe": false,
 
   // Disable proxy bypass issue.
   // Websockets have no use in Thunderbird over Tor; some versions of the
@@ -85,8 +99,11 @@ const TorBirdyPrefs = {
   // We don't want user's of Thunderbird to even come close to such a bypass
   // issue and so we have disabled websockets out of an abundance of caution.
   "network.websocket.enabled": false,
-  // No cookies are allowed.
-  "network.cookie.cookieBehavior": 2,
+  // Cookies are allowed, but not third-party cookies. For Gmail and Twitter.
+  "network.cookie.cookieBehavior": 1,
+  // http://kb.mozillazine.org/Network.cookie.lifetimePolicy
+  // 2: cookie expires at the end of the session.
+  "network.cookie.lifetimePolicy": 2,
   // Disable link prefetching.
   "network.prefetch-next": false,
 
@@ -94,15 +111,11 @@ const TorBirdyPrefs = {
     Security
   */
 
-  // Default is always false for OCSP - it's broken crap
-  // Why is it broken, you might ask?
-  // Moxie Marlinspike, a hero to all humans everywhere, defeated it with the
-  // number '3' at Defcon/Blackhat 2009 His paper:
-  // http://www.thoughtcrime.org/papers/ocsp-attack.pdf His software to perform
-  // the attack is here: http://thoughtcrime.org/software/sslsniff/ Furthermore
-  // - OCSP servers may log information about a user as they use the internet
-  // generally; it's everything we hate about CRLs and more
+  // Default is always false for OCSP.
+  // OCSP servers may log information about a user as they use the internet
+  // generally; it's everything we hate about CRLs and more.
   "security.OCSP.enabled": 1,
+  "security.OCSP.GET.enabled": false,
   "security.OCSP.require": false,
   // Disable TLS Session Ticket.
   // See https://trac.torproject.org/projects/tor/ticket/4099
@@ -111,7 +124,9 @@ const TorBirdyPrefs = {
   // We do not want to enable a known weak protocol; users should use only use TLS
   "security.enable_ssl3": false,
   // Thunderbird 23.0 uses the following preference.
+  // https://bugs.torproject.org/11253
   "security.tls.version.min": 1,
+  "security.tls.version.max": 3,
   // Display a dialog warning the user when entering an insecure site from a secure one.
   "security.warn_entering_weak": true,
   // Display a dialog warning the user when submtting a form to an insecure site.
@@ -126,6 +141,8 @@ const TorBirdyPrefs = {
   // Disable 'extension blocklist' which might leak the OS information.
   // See https://trac.torproject.org/projects/tor/ticket/6734
   "extensions.blocklist.enabled": false,
+  // Strict: certificate pinning is always enforced.
+  "security.cert_pinning.enforcement_level": 2,
 
   /*
     Mailnews
@@ -166,7 +183,7 @@ const TorBirdyPrefs = {
   */
 
   // Prevent hostname leaks.
-  "mail.smtpserver.default.hello_argument": "127.0.0.1",
+  "mail.smtpserver.default.hello_argument": "[127.0.0.1]",
   // Compose messages in plain text (by default).
   "mail.html_compose": false,
   "mail.identity.default.compose_html": false,
@@ -181,6 +198,14 @@ const TorBirdyPrefs = {
   "mail.inline_attachments": false,
   // Do not IDLE (disable push mail).
   "mail.server.default.use_idle": false,
+  // Thunderbird's autoconfig wizard is designed to enable an initial
+  // mail fetch (by setting login_at_start) for the first account it
+  // creates (which will become the "default" account, see
+  // msgMail3PaneWindow.js for details) which side-steps the settings
+  // we apply in fixupTorbirdySettingsOnNewAccount(). Hence, fool
+  // Thunderbird to think that this initial mail fetch has already
+  // been done so we get the settings we want.
+  "mail.startup.enabledMailCheckOnce": true,
 
   /*
     Browser
@@ -188,17 +213,51 @@ const TorBirdyPrefs = {
   // Disable caching.
   "browser.cache.disk.enable": false,
   "browser.cache.memory.enable": false,
+  "browser.cache.offline.enable": false,
+  "browser.formfill.enable": false,
+  "signon.autofillForms": false,
+
+  // https://bugs.torproject.org/10367
+  "datareporting.healthreport.service.enabled": false,
+  "datareporting.healthreport.uploadEnabled": false,
+  "datareporting.policy.dataSubmissionEnabled": false,
+  "datareporting.healthreport.about.reportUrl": "data:text/plain,",
+
+  // https://bugs.torproject.org/16256
+  "browser.search.countryCode": "US",
+  "browser.search.region": "US",
+  "browser.search.geoip.url": "",
+
+  // These have been copied from Tor Browser and don't apply to Thunderbird
+  // since the browser surface is limited (Gmail/Twitter) but we set them
+  // nevertheless.
+  // Disable client-side session and persistent storage.
+  "dom.storage.enabled": false,
+  // https://bugs.torproject.org/15758
+  "device.sensors.enabled": false,
+  // https://bugs.torproject.org/5293
+  "dom.battery.enabled": false,
+  // https://bugs.torproject.org/6204
+  "dom.enable_performance": false,
+  // https://bugs.torproject.org/13023
+  "dom.gamepad.enabled": false,
+  // https://bugs.torproject.org/8382
+  "dom.indexedDB.enabled": false,
+  // https://bugs.torproject.org/13024
+  "dom.enable_resource_timing": false,
+  // https://bugs.torproject.org/16336
+  "dom.enable_user_timing": false,
+  // https://bugs.torproject.org/17046
+  "dom.event.highrestimestamp.enabled": true,
+
+  // https://bugs.torproject.org/11817
+  "extensions.getAddons.cache.enabled": false,
 
   /*
     Enigmail
   */
 
   // We hope the user has Enigmail and if so, we believe these improve security.
-  // We would like these options to be a single shared option we can toggle but
-  // we require some discussions with upstream and then they would need a new
-  // release. It's not actually clear how we could or even if we should then
-  // depend on a specific Enigmail version. Either way, we want to save the
-  // user who would shoot themselves in the privacy-foot.
 
   // Disable X-Enigmail headers.
   // We don't want to obviously disclose that we're using Enigmail as it may
@@ -215,53 +274,16 @@ const TorBirdyPrefs = {
                                               // We want to force UTF-8 everywhere
                                               "--display-charset utf-8 " +
                                               // We want to ensure that Enigmail is proxy aware even when it runs gpg in a shell
-                                              "--keyserver-options http-proxy=http://127.0.0.1:8118 ",
+                                              "--keyserver-options http-proxy=socks5h://127.0.0.1:9150 ",
                                             
   // The default key server should be a hidden service and this is the only known one (it's part of the normal SKS network)
   "extensions.enigmail.keyserver": "hkp://qdigse2yzvuglcix.onion",
-
   // Force GnuPG to use SHA512.
   "extensions.enigmail.mimeHashAlgorithm": 5,
 
-  // Prefer plain text for RSS.
-  "rss.display.prefer_plaintext": true,
-
-  // Override the user agent by setting it to an empty string.
-  "general.useragent.override": "",
-
-  // Disable WebGL.
-  "webgl.disabled": true,
-
-  // Disable Telemetry completely.
-  "toolkit.telemetry.enabled": false,
-
-  // Disable Geolocation.
-  "geo.enabled": false,
-
-  // Disable JavaScript (email).
-  "javascript.enabled": false,
-
-  // Disable client-side session and persistent storage.
-  "dom.storage.enabled": false,
-  // Do not run plugins out-of-process.
-  "dom.ipc.plugins.java.enabled": false,
-  // Disable changing of images via JavaScript.
-  "dom.disable_image_src_set": true,
-
-  // Disable WebM, WAV, Ogg, PeerConnection.
-  "media.webm.enabled": false,
-  "media.wave.enabled": false,
-  "media.ogg.enabled": false,
-  "media.peerconnection.enabled": false,
-
-  // Disable CSS :visited selector.
-  "layout.css.visited_links_enabled": false,
-
-  // Disable downloadable fonts.
-  "gfx.downloadable_fonts.enabled": false,
-
-  // Disable remote images.
-  "permissions.default.image": 2,
+  /*
+    Chat and Calendar
+  */
 
   // Thunderbird 15 introduces the chat feature so disable the preferences below.
   "purple.logging.log_chats": false,
@@ -290,7 +312,52 @@ const TorBirdyPrefs = {
 
   // Mozilla Lightning.
   "calendar.useragent.extra": "",
-  "calendar.timezone.local": "",
+  // We have to set a timezone otherwise the system time is used. "UTC" or
+  // "GMT" is not an option so we set it to Europe/London.
+  "calendar.timezone.local": "Europe/London",
+
+  /*
+   Other Settings
+  */
+
+  // RSS.
+  "rss.display.prefer_plaintext": true,
+  // These are similar to the mailnews.* settings.
+  "rss.display.disallow_mime_handlers": 3,
+  "rss.display.html_as": 1,
+
+  // Override the user agent by setting it to an empty string.
+  "general.useragent.override": "",
+
+  // Disable WebGL.
+  "webgl.disabled": true,
+
+  // Disable Telemetry completely.
+  "toolkit.telemetry.enabled": false,
+
+  // Disable Geolocation.
+  "geo.enabled": false,
+
+  // Disable JavaScript (email).
+  "javascript.enabled": false,
+
+  // Disable WebM, WAV, Ogg, PeerConnection.
+  "media.navigator.enabled": false,
+  "media.peerconnection.enabled": false,
+  "media.cache_size": 0,
+
+  // Disable CSS :visited selector.
+  "layout.css.visited_links_enabled": false,
+
+  // Disable downloadable fonts.
+  "gfx.downloadable_fonts.enabled": false,
+
+  // Disable third-party images.
+  "permissions.default.image": 3,
+
+  /*
+   Finish
+  */
 
   // All preferences have been set: now enable TorBirdy.
   "extensions.torbirdy.protected": true,
@@ -312,6 +379,27 @@ var TorBirdyOldPrefs = [
   "network.proxy.http",
 ]
 
+// sanitizeDateHeaders()
+// Run this function to make sure that the Date header in a new message
+// is rounded down to the nearest minute.
+function sanitizeDateHeaders() {
+  // Import the jsmime module that is used to generate mail headers.
+  let { jsmime } = Cu.import("resource:///modules/jsmime.jsm");
+  // Inject our own structured encoder to the default header emitter,
+  // to override the default Date encoder with a rounded-down version.
+  jsmime.headeremitter.addStructuredEncoder("Date", function (date) {
+    // Copy date
+    let roundedDate = new Date(date.getTime());
+    // Round down to the nearest minute.
+    roundedDate.setSeconds(0);
+    // Use the headeremitter's internal `addText` function to inject the
+    // Date header. `this` magically refers to the headeremitter object.
+    // Date.toUTCString() produces an RFC 1123-formatted date string.
+    // We replace the "GMT" symbol with "+0000" because it is preferred.
+    this.addText(roundedDate.toUTCString().replace(/GMT$/, "+0000"), false);
+  });
+}
+
 function TorBirdy() {
   this._uninstall = false;
   this.wrappedJSObject = this;
@@ -339,6 +427,7 @@ function TorBirdy() {
 
   this.setAccountPrefs();
   this.setPrefs();
+  sanitizeDateHeaders();
 
   dump("TorBirdy registered!\n");
 }
@@ -355,17 +444,33 @@ TorBirdy.prototype = {
   // This is a hack to cause Thunderbird to instantiate us ASAP!
   _xpcom_categories: [{ category: "profile-after-change"}, ],
 
+  onStateChange: function() {
+    let panel = Cc['@mozilla.org/appshell/window-mediator;1']
+             .getService(Ci.nsIWindowMediator)
+             .getMostRecentWindow('mail:3pane').document.getElementById("torbirdy-my-panel");
+    if (this._uninstall) {
+      panel.label = _("torbirdy.enabled");
+      panel.style.color = "green";
+    }
+    else {
+      panel.label = _("torbirdy.disabled");
+      panel.style.color = "red";
+    }
+  },
+
   onUninstalling: function(addon, needsRestart) {
+    this.onStateChange();
     if (addon.id == TB_ID) {
-      dump("Nooo! TorBirdy uninstall requested\n");
+      dump("TorBirdy uninstall requested\n");
       this._uninstall = true;
       this.resetUserPrefs();
     }
   },
 
   onOperationCancelled: function(addon) {
+    this.onStateChange();
     if (addon.id == TB_ID) {
-      dump("Uninstall requested cancelled. Yayay!\n");
+      dump("Uninstall requested cancelled\n");
       this._uninstall = false;
       this.setPrefs();
     }
@@ -378,13 +483,13 @@ TorBirdy.prototype = {
   resetUserPrefs: function() {
     dump("Resetting user preferences to default\n");
     // Clear the Thunderbird preferences we changed.
-    for (var each in TorBirdyPrefs) {
+    for (let each in TorBirdyPrefs) {
       this.prefs.clearUserPref(each);
     }
 
     // Restore the older proxy preferences that were set prior to TorBirdy's install.
     dump("Restoring proxy settings\n");
-    for (var i = 0; i < TorBirdyOldPrefs.length; i++) {
+    for (let i = 0; i < TorBirdyOldPrefs.length; i++) {
       var oldPref = TorBirdyOldPrefs[i];
       var setValue = kRestoreBranch + oldPref;
       var type = this.prefs.getPrefType(setValue);
@@ -400,14 +505,14 @@ TorBirdy.prototype = {
     }
 
     // Enable plugins.
-    for(var i = 0; i < this.plugins.length; i++) {
+    for(let i = 0; i < this.plugins.length; i++) {
         this.plugins[i].disabled = false;
     }
 
     // Now clear all TorBirdy preferences.
     var clearPrefs = Cc["@mozilla.org/preferences-service;1"]
                              .getService(Ci.nsIPrefService).getBranch(kTorBirdyBranch).getChildList("", {});
-    for (var i = 0; i < clearPrefs.length; i++) {
+    for (let i = 0; i < clearPrefs.length; i++) {
         this.prefs.clearUserPref(kTorBirdyBranch + clearPrefs[i]);
     }
   },
@@ -415,7 +520,7 @@ TorBirdy.prototype = {
   setPrefs: function() {
     // If custom values are set for specific preferences, override the defaults with them.
     // For each preference, get the type and then set the property.
-    for (var i = 0; i < this.customPrefs.length; i++) {
+    for (let i = 0; i < this.customPrefs.length; i++) {
       var typePref = this.prefs.getPrefType(this.customPrefs[i]);
       // String.
       if (typePref === 32) {
@@ -432,7 +537,7 @@ TorBirdy.prototype = {
       TorBirdyPrefs[this.customPrefs[i]] = value;
     }
 
-    for (var each in TorBirdyPrefs) {
+    for (let each in TorBirdyPrefs) {
       if (typeof TorBirdyPrefs[each] === "boolean") {
         this.prefs.setBoolPref(each, TorBirdyPrefs[each]);
       }
@@ -452,7 +557,7 @@ TorBirdy.prototype = {
       // First copy TorBirdyPrefs to TorBirdyOldPrefs.
       TorBirdyOldPrefs.push.apply(TorBirdyOldPrefs, Object.keys(TorBirdyPrefs));
 
-      for (var i = 0; i < TorBirdyOldPrefs.length; i++) {
+      for (let i = 0; i < TorBirdyOldPrefs.length; i++) {
         var oldPref = TorBirdyOldPrefs[i];
         var type = this.prefs.getPrefType(oldPref);
         // String.
@@ -486,7 +591,7 @@ TorBirdy.prototype = {
       this.prefs.setIntPref("network.proxy.ssl_port", 0);
 
       // Disable all plugins.
-      for (var i = 0; i < this.plugins.length; i++) {
+      for (let i = 0; i < this.plugins.length; i++) {
           this.plugins[i].disabled = true;
       }
 
@@ -498,37 +603,31 @@ TorBirdy.prototype = {
       var allAccounts = [];
       // To maintain compatibility between Gecko 17+ and Gecko < 17, find out
       // which version we are on.
-      var newGecko = (accounts.queryElementAt) ? true : false;
 
-      var accountLength = newGecko ? accounts.length : accounts.Count();
-      for (var i = 0; i < accountLength; i++) {
-        var account = (newGecko) ?
-                      accounts.queryElementAt(i, Ci.nsIMsgAccount) :
-                      accounts.QueryElementAt(i, Ci.nsIMsgAccount);
+      var accountLength = accounts.length;
+      for (let i = 0; i < accountLength; i++) {
+        var account = accounts.queryElementAt(i, Ci.nsIMsgAccount);
         allAccounts.push(account);
       }
 
       // Save account settings for restoring later.
-      for (var i = 0; i < allAccounts.length; i++) {
+      for (let i = 0; i < allAccounts.length; i++) {
         var identities = allAccounts[i].identities;
         var account = allAccounts[i].incomingServer;
 
         // Get the locations of the Draft folder for all identities and save them.
         // We only need to do this for IMAP accounts.
         if (account.type === "imap") {
-          // Again ensure we maintain compatibility between different Gecko versions.
-          var identLength = newGecko ? identities.length : identities.Count();
+          var identLength = identities.length;
 
-          for (var ident = 0; ident < identLength; ident++) {
-            var identity = (newGecko) ?
-                           identities.queryElementAt(ident, Ci.nsIMsgIdentity) :
-                           identities.QueryElementAt(ident, Ci.nsIMsgIdentity);
+          for (let ident = 0; ident < identLength; ident++) {
+            var identity = identities.queryElementAt(ident, Ci.nsIMsgIdentity);
 
             var key = identity.key;
             // We need to restore the following preferences after we are uninstalled/disabled.
             var restorePrefs = ["draft_folder", "drafts_folder_picker_mode"];
 
-            for (var p = 0; p < restorePrefs.length; p++) {
+            for (let p = 0; p < restorePrefs.length; p++) {
               var pref = "mail.identity.%id%.".replace("%id%", key);
               var prefName = pref + restorePrefs[p];
               if (this.prefs.prefHasUserValue(prefName)) {
@@ -550,7 +649,7 @@ TorBirdy.prototype = {
         var restorePrefs = ["check_new_mail", "login_at_startup",
                             "check_time", "download_on_biff",
                             "socketType", "port", "authMethod"];
-        for (var j = 0; j < restorePrefs.length; j++) {
+        for (let j = 0; j < restorePrefs.length; j++) {
           var pref = "mail.server.%serverkey%.".replace("%serverkey%", key);
           var prefName = restorePrefs[j];
           var prefToCall = pref + prefName;
@@ -591,10 +690,34 @@ TorBirdy.prototype = {
         // Set the authentication to normal, connection is already encrypted.
         account.authMethod = 3;
       }
+
+      // We need to set safe defaults for the outgoing servers in case there
+      // are accounts using insecure configurations. One other way way of
+      // accessing the server list can be through nsIMsgIdentity but multiple
+      // identities can share the same server so fetching the preference value
+      // mail.smtpservers seems a better way to do it.
+      let smtpAccounts = this.prefs.getCharPref("mail.smtpservers").split(",");
+      let smtpPrefs = [
+        ["mail.smtpserver.%smtp%.port", 465], // SMTP over TLS
+        ["mail.smtpserver.%smtp%.authMethod", 3], // Normal password
+        ["mail.smtpserver.%smtp%.try_ssl", 3], // SSL/TLS
+      ];
+      for (let i = 0; i < smtpAccounts.length; i++) {
+        for each (var [pref_template, value] in smtpPrefs) {
+          let pref = pref_template.replace("%smtp%", smtpAccounts[i]);
+          if (this.prefs.prefHasUserValue(pref)) {
+            let currentPref = Preferences.get(pref);
+            // Save the values so that we can restore them later.
+            Preferences.set(kRestoreBranch + pref, currentPref);
+            TorBirdyOldPrefs.push(pref);
+            Preferences.set(pref, value);
+          }
+        }
+      }
     }
     this.prefs.setBoolPref("extensions.torbirdy.first_run", false);
   },
 
 }
 
-const NSGetFactory = XPCOMUtils.generateNSGetFactory([TorBirdy]);
+var NSGetFactory = XPCOMUtils.generateNSGetFactory([TorBirdy]);
